# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.maps.routing.v2",
    manifest={
        "Units",
    },
)


class Units(proto.Enum):
    r"""A set of values that specify the unit of measure used in the
    display.

    Values:
        UNITS_UNSPECIFIED (0):
            Units of measure not specified. Defaults to
            the unit of measure inferred from the request.
        METRIC (1):
            Metric units of measure.
        IMPERIAL (2):
            Imperial (English) units of measure.
    """
    UNITS_UNSPECIFIED = 0
    METRIC = 1
    IMPERIAL = 2


__all__ = tuple(sorted(__protobuf__.manifest))
